CompilerOptions

Struct CompilerOptions 

#[non_exhaustive]
pub struct CompilerOptions { pub shader_model: ShaderModel, pub point_size_compat: bool, pub point_coord_compat: bool, pub vertex: CompilerVertexOptions, pub force_storage_buffer_as_uav: bool, pub nonwritable_uav_texture_as_srv: bool, pub force_zero_initialized_variables: bool, pub entry_point: Option<(String, ExecutionModel)>, }
HLSL compiler options.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
shader_model: ShaderModelpoint_size_compat: bool

Support point size builtin but ignore the value.

point_coord_compat: bool

Support point coordinate builtin but ignore the value.

vertex: CompilerVertexOptionsforce_storage_buffer_as_uav: boolnonwritable_uav_texture_as_srv: boolforce_zero_initialized_variables: bool

Whether to force all uninitialized variables to be initialized to zero.

entry_point: Option<(String, ExecutionModel)>

The name and execution model of the entry point to use. If no entry point is specified, then the first entry point found will be used.