CompilerOptions

Struct CompilerOptions 

#[non_exhaustive]
pub struct CompilerOptions {
Show 14 fields pub version: Version, pub force_temporary: bool, pub vulkan_semantics: bool, pub separate_shader_objects: bool, pub flatten_multidimensional_arrays: bool, pub enable_420_pack_extension: bool, pub emit_push_constant_as_uniform_buffer: bool, pub emit_uniform_buffer_as_plain_uniforms: bool, pub emit_line_directives: bool, pub enable_storage_image_qualifier_deduction: bool, pub force_zero_initialized_variables: bool, pub vertex: CompilerVertexOptions, pub fragment: CompilerFragmentOptions, pub entry_point: Option<(String, ExecutionModel)>,
}
GLSL compiler options.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
version: Versionforce_temporary: boolvulkan_semantics: boolseparate_shader_objects: boolflatten_multidimensional_arrays: boolenable_420_pack_extension: boolemit_push_constant_as_uniform_buffer: boolemit_uniform_buffer_as_plain_uniforms: boolemit_line_directives: boolenable_storage_image_qualifier_deduction: boolforce_zero_initialized_variables: bool

Whether to force all uninitialized variables to be initialized to zero.

vertex: CompilerVertexOptionsfragment: CompilerFragmentOptionsentry_point: Option<(String, ExecutionModel)>

The name and execution model of the entry point to use. If no entry point is specified, then the first entry point found will be used.